import 'package:flutter/material.dart';
import 'package:geideadesignframework/gediea_app_bar.dart';
import 'package:geideadesignframework/gediea_app_drawer.dart';
import 'package:geideadesignframework/geidea_bottom_modal.dart';
import 'package:geideadesignframework/geidea_toggle_buttons.dart';
import 'package:geideadesignframework/main.dart';
import 'package:geideadesignframework/main_button.dart';
import 'package:geideadesignframework/monstserrat_text.dart';
import 'package:geideadesignframework/secondary_button.dart';
import 'package:geideadesignframework/subscreens/chips_preview.dart';
import 'package:geideadesignframework/subscreens/inputs_preview.dart';
import 'package:geideadesignframework/subscreens/others_preview.dart';
import 'package:geideadesignframework/subscreens/slider_preview.dart';
import 'package:geideadesignframework/subscreens/typography_preview.dart';
import 'package:geideadesignframework/subscreens/widgets_preview.dart';
import 'package:geideadesignframework/text_field.dart';
import 'package:geideadesignframework/GeideaTheme.dart';


class AllComponents extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'All Components',
      color: GeideaColors.orange[500],
      theme: GeideaTheme,
      home: AllComponentsHomePage(title: 'Geidea Design Framework'),
    );
  }
}

class AllComponentsHomePage extends StatefulWidget {
  AllComponentsHomePage({Key key, this.title}) : super(key: key);

  // This widget is the home page of your application. It is stateful, meaning
  // that it has a State object (defined below) that contains fields that affect
  // how it looks.

  // This class is the configuration for the state. It holds the values (in this
  // case the title) provided by the parent (in this case the App widget) and
  // used by the build method of the State. Fields in a Widget subclass are
  // always marked "final".

  final String title;

  @override
  _AllComponentsHomePageState createState() => _AllComponentsHomePageState();
}

class TabItem {
  final String text;
  final IconData icon;

  TabItem(this.text, this.icon);
}
class _AllComponentsHomePageState extends State<AllComponentsHomePage>   with SingleTickerProviderStateMixin {
  // RepaintBoundary key
  GlobalKey _globalKey = new GlobalKey();

  final _tabsItem = [
    TabItem('Controls', Icons.check_box),
    TabItem('Buttons', Icons.touch_app),
    TabItem('Inputs', Icons.keyboard),
    TabItem('Slider', Icons.tune),
    TabItem('Chips', Icons.dns),
    TabItem('Others', Icons.people),
    TabItem('Text', Icons.text_fields),
    TabItem('Primary Text', Icons.text_fields),
    TabItem('Accent Text', Icons.text_fields),
    /*TabItem('Color scheme', Icons.color_lens),*/
  ];

  TabController tabBarController;

  bool showFAB = true;

  get bottomItems => [
    {'label': 'Map', 'icon': Icons.map},
    {'label': 'Description', 'icon': Icons.description},
    {'label': 'Transform', 'icon': Icons.transform},
  ]
      .map<Widget>((item) => IconButton(
    icon: Icon(item['icon']),
    onPressed: () {},
  )
    /*BottomNavigationBarItem(
                icon: Icon(item['icon']),
                title: Text(item['label']),
              )*/
  )
      .toList();

  @override
  void initState() {
    super.initState();
    tabBarController = TabController(length: _tabsItem.length, vsync: this);
    tabBarController.addListener(() {
      setState(() {
        showFAB = tabBarController.index == 0;
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return RepaintBoundary(
      key: _globalKey,
      child: AnimatedTheme(
        data: Theme.of(context),
        child: DefaultTabController(
          length: _tabsItem.length,
          child: Scaffold(
            appBar: AppBar(
              title: Text("App Preview"),
              bottom: _buildTabBar(),
              actions: <Widget>[
                IconButton(icon: Icon(Icons.add), onPressed: () {}),
                IconButton(
                    icon: Icon(Icons.add_a_photo)),
                /*IconButton(
                      icon: Icon(Icons.create_new_folder),
                      onPressed: () => Scaffold.of(context).openDrawer()),*/
              ],
            ),
            floatingActionButton: tabBarController.index == 0
                ? FloatingActionButton(
                child: Icon(
                  Icons.check,
                  /*color: Theme.of(context)?.accentTextTheme?.button?.color,*/
                ),
                onPressed: () {})
                : null,
            floatingActionButtonLocation:
            FloatingActionButtonLocation.endDocked,
            drawer: GedieaAppDrawer(
                color: Colors.white,
                fontSize: 20.0,
                iconSize: 30,
                paddingVertical: 15.0,
                paddingHorizontal: 40.0,
                items: [
                  {'iconName': 'home', 'text': 'Home', 'onTap': () {}},
                  {'iconName': 'cash-drawer', 'text': 'Cash Drawer', 'onTap': () {}},
                  {
                    'iconName': 'drawer-history',
                    'text': 'Payout History',
                    'onTap': () {}
                  },
                  {
                    'iconName': 'transaction-history',
                    'text': 'Transaction History',
                    'onTap': () {}
                  },
                  {'iconName': 'reporting', 'text': 'Reporting', 'onTap': () {}},
                  {'iconName': 'more', 'text': 'More', 'onTap': () {}},
                ]),
            body: TabBarView(controller: tabBarController, children: [
              WidgetPreview1(theme: Theme.of(context)),
              ButtonPreview(theme: Theme.of(context)),
              InputsPreview(theme: Theme.of(context)),
              SliderPreview(theme: Theme.of(context)),
              ChipsPreview(theme: Theme.of(context)),
              OthersPreview(theme: Theme.of(context)),
              TypographyPreview(
                textTheme: Theme.of(context).textTheme,
                brightness: Theme.of(context).brightness,
              ),
              TypographyPreview(
                textTheme: Theme.of(context).primaryTextTheme,
                brightness: Theme.of(context).primaryColorBrightness,
              ),
              TypographyPreview(
                textTheme: Theme.of(context).accentTextTheme,
                brightness: Theme.of(context).accentColorBrightness,
              ),
            ]),
            bottomNavigationBar: BottomAppBar(
              child: Row(children: bottomItems),
              shape: CircularNotchedRectangle(),
            ),
          ),
        ),
      ),
    );
  }

  _buildTabBar() => TabBar(
      isScrollable: true,
      controller: tabBarController,
      tabs:
      _tabsItem.map((t) => Tab(text: t.text, icon: Icon(t.icon))).toList());

}